System.register(['./generated-main1.js'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports('ItemOne', module.a);
		}],
		execute: (function () {



		})
	};
}));
